@@ -45,7 +45,7 @@
     <message>
         <location filename="../obconf.ui" line="46"/>
         <source>Move &amp; Resize</source>
-        <translation>Muuda aknaid</translation>
+        <translation>Liigutamine &amp; suuruse muutmine</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="51"/>
@@ -80,7 +80,7 @@
     <message>
         <location filename="../obconf.ui" line="108"/>
         <source>&amp;Windows retain a border when undecorated</source>
-        <translation type="unfinished"></translation>
+        <translation>Dekoreerimata &amp;aknad säilitavad äärise</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="115"/>
@@ -106,318 +106,324 @@ M: Maximize
 C: Close
 S: Shade (Roll up)
 D: Omnipresent (On all desktops)</source>
-        <translation type="unfinished"></translation>
+        <translation>N: Akna ikoon
+L: Akna nimi (Tiitel)
+I: Minimeerimine
+M: Maksimeerimine
+C: Sulgemine
+S: Kokku kerimine
+D: Kõikjal (Igal tööalal)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="219"/>
         <source>&amp;Active window title: </source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Aktiivse akna pealkiri: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="229"/>
         <source>&amp;Inactive window title: </source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Mitteaktiivse akna pealkiri: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="239"/>
         <source>Menu &amp;header: </source>
-        <translation type="unfinished"></translation>
+        <translation>Menüü &amp;päis: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="249"/>
         <source>&amp;Menu Item: </source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Menüükirje: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="259"/>
         <source>Active &amp;On-screen display: </source>
-        <translation type="unfinished"></translation>
+        <translation>Aktiivne &amp;kuvatav ekraan: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="269"/>
         <source>Inactive O&amp;n-screen display: </source>
-        <translation type="unfinished"></translation>
+        <translation>Mitteaktiivne ekraanil kuvatav ekraan: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="283"/>
         <source>Focus &amp;new windows when they appear</source>
-        <translation type="unfinished"></translation>
+        <translation>Fokusseeri uutele ake&amp;ndele, kui nad ilmuvad</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="290"/>
         <source>&amp;Place new windows under the mouse pointer</source>
-        <translation type="unfinished"></translation>
+        <translation>A&amp;seta uued aknad hiire kursori alla</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="297"/>
         <source>&amp;Center new windows when they are placed</source>
-        <translation type="unfinished"></translation>
+        <translation>Joonda uued aknad keskele</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="306"/>
         <source>Prefer to place new windows &amp;on:</source>
-        <translation type="unfinished"></translation>
+        <translation>Eelista asetada akna_d:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="317"/>
         <source>All monitors</source>
-        <translation type="unfinished"></translation>
+        <translation>Kõik monitorid</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="322"/>
         <source>The active monitor</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktiivne monitor</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="327"/>
         <source>The monitor with the mouse</source>
-        <translation type="unfinished"></translation>
+        <translation>See monitor, kus asub hiir</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="332"/>
         <source>Primary monitor</source>
-        <translation type="unfinished"></translation>
+        <translation>Primaarne monitor</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="342"/>
         <source>Primary Monitor</source>
-        <translation type="unfinished"></translation>
+        <translation>Primaarne monitor</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="348"/>
         <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
-        <translation type="unfinished"></translation>
+        <translation>Primaarne monitor on koht, kuhu OpenBox asetab dialoogi, näiteks akende vahetamise jaoks.</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="358"/>
         <source>Primary &amp;monitor:</source>
-        <translation type="unfinished"></translation>
+        <translation>Primaarne &amp;monitor:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="369"/>
         <source>Fixed Monitor</source>
-        <translation type="unfinished"></translation>
+        <translation>Fikseeritud monitor</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="374"/>
         <source>Active Monitor</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktiivne monitor</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="379"/>
         <source>Monitor With Mouse Pointer</source>
-        <translation type="unfinished"></translation>
+        <translation>Monitor hiire pointeriga</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="387"/>
         <source>&amp;Fixed monitor:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Fikseeritud monitor:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="427"/>
         <source>Moving and Resizing Windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Akende liigutamine ja suuruse muutmine</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="433"/>
         <source>Update the window contents while &amp;resizing</source>
-        <translation type="unfinished"></translation>
+        <translation>Värskenda akende sisu, kui nende suu&amp;rust muudetakse</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="440"/>
         <source>Drag &amp;threshold distance:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tirimise vahemaa lävi:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="460"/>
         <source>Amount of resistance against other &amp;windows:</source>
-        <translation type="unfinished"></translation>
+        <translation>Teiste a&amp;kende vaheline vastupanu:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="480"/>
         <source>Amount of resistance against screen &amp;edges:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Ekraani servade vaheline vastupanu:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="500"/>
         <source>&amp;Amount of time to wait before switching:</source>
-        <translation type="unfinished"></translation>
+        <translation>Kui k&amp;aua oodata enne vahetamist:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="520"/>
         <source>&amp;Switch desktops when moving a window past the screen edge</source>
-        <translation type="unfinished"></translation>
+        <translation>Vaheta töölaudu, kui aken liigutatakse ekraani &amp;servast mööda</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="530"/>
         <source>Information Dialog</source>
-        <translation type="unfinished"></translation>
+        <translation>Info dialoogi</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="537"/>
         <location filename="../obconf.ui" line="566"/>
         <source>Centered</source>
-        <translation type="unfinished"></translation>
+        <translation>Keskel</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="542"/>
         <source>From left edge</source>
-        <translation type="unfinished"></translation>
+        <translation>Vasakust servast</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="547"/>
         <source>From right edge</source>
-        <translation type="unfinished"></translation>
+        <translation>Paremast servast</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="555"/>
         <source>Fixed &amp;y position:</source>
-        <translation type="unfinished"></translation>
+        <translation>Fikseeritud &amp;y asukoht:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="571"/>
         <source>From top edge</source>
-        <translation type="unfinished"></translation>
+        <translation>Ülemisest servast</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="576"/>
         <source>From bottom edge</source>
-        <translation type="unfinished"></translation>
+        <translation>Alumisest servast</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="584"/>
         <source>Information dialog&apos;s &amp;position:</source>
-        <translation type="unfinished"></translation>
+        <translation>Info dialoogi &amp;asukoht:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="594"/>
         <source>Fixed &amp;x position:</source>
-        <translation type="unfinished"></translation>
+        <translation>Fikseeritud &amp;x asukoht:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="604"/>
         <source>Show &amp;information dialog:</source>
-        <translation type="unfinished"></translation>
+        <translation>Kuva _info dialoog:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="629"/>
         <source>When resizing terminal windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Terminali akende suuruse muutmisel</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="634"/>
         <source>Always</source>
-        <translation type="unfinished"></translation>
+        <translation>Alati</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="639"/>
         <source>Never</source>
-        <translation type="unfinished"></translation>
+        <translation>Mitte kunagi</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="648"/>
         <source>Centered on the window</source>
-        <translation type="unfinished"></translation>
+        <translation>Joondatud akna keskele</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="653"/>
         <source>Above the window</source>
-        <translation type="unfinished"></translation>
+        <translation>Akna kohal</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="658"/>
         <source>Fixed position on screen</source>
-        <translation type="unfinished"></translation>
+        <translation>Fikseeritud asukoht ekraanil</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="689"/>
         <source>Focusing Windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Akende fokusseerimine</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="698"/>
         <source>Focus windows when the mouse pointer moves over them</source>
-        <translation type="unfinished"></translation>
+        <translation>Fokusseeri aken, kui hiire kursor liigub nende kohale</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="710"/>
         <source>&amp;Delay before focusing and raising windows:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Viivitus enne fokuseerimist ja akna tõstmist:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="730"/>
         <source>Move focus under the mouse when &amp;switching desktops</source>
-        <translation type="unfinished"></translation>
+        <translation>Liiguta fookus hiire alla, kui &amp;vahetad töölauda</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="737"/>
         <source>Move focus &amp;under the mouse when the mouse is not moving</source>
-        <translation type="unfinished"></translation>
+        <translation>Liiguta fookus hiire &amp;alla, kui hiir ei liigu</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="744"/>
         <source>&amp;Raise windows when the mouse pointer moves over them</source>
-        <translation type="unfinished"></translation>
+        <translation>T&amp;õsta aken, kui hiire kursor liigub üle tema</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="756"/>
         <source>Titlebar</source>
-        <translation type="unfinished"></translation>
+        <translation>Tiitliriba</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="762"/>
         <source>Double click on the &amp;titlebar:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Topeltklõps pealkirjaribal:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="773"/>
         <source>Maximizes the window</source>
-        <translation type="unfinished"></translation>
+        <translation>Maksimeerib akna</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="778"/>
         <source>Shades the window</source>
-        <translation type="unfinished"></translation>
+        <translation>Varjab akna</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="786"/>
         <source>Double click ti&amp;me:</source>
-        <translation type="unfinished"></translation>
+        <translation>Topeltklõpsu aeg:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="826"/>
         <source>&amp;Show a notification when switching desktops</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Töölaua vahetamisel kuvatakse teade</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="833"/>
         <source>&amp;Amount of time to show the notification for:</source>
-        <translation type="unfinished"></translation>
+        <translation>Kui kaua &amp;teadet kuvatakse:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="856"/>
         <source>&amp;Number of desktops: </source>
-        <translation type="unfinished"></translation>
+        <translation>Töö&amp;laudade arv: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="879"/>
         <source>&amp;Desktop names:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Töölaudade nimed:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="893"/>
         <source>Desktop Margins</source>
-        <translation type="unfinished"></translation>
+        <translation>Töölaua veerised</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="899"/>
         <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
-        <translation type="unfinished"></translation>
+        <translation>Töölaua veerised on ekraanil reserveeritud alad. Uusi aknaid ei asetata veerisele ja maksimeeritud aknad ei kata seda ala.</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="909"/>
         <source>Left:</source>
-        <translation type="unfinished"></translation>
+        <translation>Vasakul:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="923"/>
@@ -425,157 +431,157 @@ D: Omnipresent (On all desktops)</source>
         <location filename="../obconf.ui" line="965"/>
         <location filename="../obconf.ui" line="986"/>
         <source>px</source>
-        <translation type="unfinished"></translation>
+        <translation>px</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="930"/>
         <source>Top:</source>
-        <translation type="unfinished"></translation>
+        <translation>Üleval:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="951"/>
         <source>Right:</source>
-        <translation type="unfinished"></translation>
+        <translation>Paremal:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="972"/>
         <source>Bottom:</source>
-        <translation type="unfinished"></translation>
+        <translation>All:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1013"/>
         <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
-        <translation type="unfinished"></translation>
+        <translation>Dokk on spetsiaalne konteiner &quot;doki rakendustele&quot;. Ta ei ole nähtav, kui doki rakendused ei tööta. Doki rakendused võivad kuvada näiteks kella või pakkuda sulle teateala.</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1029"/>
         <source>Position</source>
-        <translation type="unfinished"></translation>
+        <translation>Paigutus</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1041"/>
         <source>&amp;Position:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Paigutus:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1055"/>
         <source>Top Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Üleval vasakul</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1060"/>
         <source>Top</source>
-        <translation type="unfinished"></translation>
+        <translation>Üleval</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1065"/>
         <source>Top Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Üleval paremal</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1070"/>
         <source>Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Vasakul</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1075"/>
         <source>Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Paremal</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1080"/>
         <source>Bottom Left</source>
-        <translation type="unfinished"></translation>
+        <translation>All vasakul</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1085"/>
         <source>Bottom</source>
-        <translation type="unfinished"></translation>
+        <translation>All</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1090"/>
         <source>Bottom Right</source>
-        <translation type="unfinished"></translation>
+        <translation>All paremal</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1095"/>
         <source>Floating</source>
-        <translation type="unfinished"></translation>
+        <translation>Ujuv</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1109"/>
         <source>&amp;Floating position:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Ujuv asukoht:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1134"/>
         <source>x</source>
-        <translation type="unfinished"></translation>
+        <translation>x</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1150"/>
         <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
-        <translation type="unfinished"></translation>
+        <translation>Luba &amp;aknaid paigutada doki piirkonda</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1157"/>
         <source>&amp;Orientation: </source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Suund: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1171"/>
         <source>Vertical</source>
-        <translation type="unfinished"></translation>
+        <translation>Vertikaalne</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1176"/>
         <source>Horizontal</source>
-        <translation type="unfinished"></translation>
+        <translation>Horisontaalne</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1187"/>
         <source>Stacking</source>
-        <translation type="unfinished"></translation>
+        <translation>Virnastamine</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1193"/>
         <source>Keep dock &amp;above other windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Hoia dokk teiste akende &amp;kohal</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1200"/>
         <source>A&amp;llow dock to be both above and below windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Luba dokil olla nii akende kohal, kui ka all</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1207"/>
         <source>Keep dock &amp;below other windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Hoia dokk teiste akende &amp;all</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1217"/>
         <source>Hiding</source>
-        <translation type="unfinished"></translation>
+        <translation>Peitmine</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1223"/>
         <source>&amp;Delay before hiding:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Viivitus enne peitmist:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1233"/>
         <source>Delay before &amp;showing:</source>
-        <translation type="unfinished"></translation>
+        <translation>Viivitus enne näitami&amp;st:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1263"/>
         <source>&amp;Hide off screen</source>
-        <translation type="unfinished"></translation>
+        <translation>_Peida ekraan</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1294"/>
         <source>About</source>
-        <translation type="unfinished"></translation>
+        <translation>Rakenduse teave</translation>
     </message>
 </context>
 <context>
@@ -583,24 +589,24 @@ D: Omnipresent (On all desktops)</source>
     <message>
         <location filename="../theme.cpp" line="149"/>
         <source>Choose an Openbox theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Vali Openboxi teema</translation>
     </message>
     <message>
         <location filename="../desktops.cpp" line="65"/>
         <location filename="../desktops.cpp" line="87"/>
         <location filename="../desktops.cpp" line="99"/>
         <source>(Unnamed desktop)</source>
-        <translation type="unfinished"></translation>
+        <translation>(Nimetu töölaud)</translation>
     </message>
     <message>
         <location filename="../mouse.cpp" line="57"/>
         <source>Custom actions</source>
-        <translation type="unfinished"></translation>
+        <translation>Kohandatud tegevused</translation>
     </message>
     <message>
         <location filename="../maindialog.cpp" line="78"/>
         <source>About ObConf-Qt</source>
-        <translation type="unfinished"></translation>
+        <translation>ObConf-Qt teave</translation>
     </message>
     <message>
         <location filename="../maindialog.cpp" line="79"/>
@@ -615,7 +621,17 @@ The program is based on ObConf developed by the following developers.
 * Dana Jansens &lt;danakj@orodu.net&gt;
 * Tim Riley &lt;tr@slackzone.org&gt;
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Openboxi eelistuste haldur
+
+Autoriõigus (c) 2014-2015
+
+Autorid:
+* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
+
+Programm põhineb ObConf-il, mis on välja töötatud järgmiste arendajate poolt.
+* Dana Jansens &lt;danakj@orodu.net&gt;
+* Tim Riley &lt;tr@slackzone.org&gt;
+* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
     </message>
 </context>
 <context>
@@ -623,40 +639,42 @@ The program is based on ObConf developed by the following developers.
     <message>
         <location filename="../archive.cpp" line="26"/>
         <source>&quot;%1&quot; was installed to %2</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; paigaldati %2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="53"/>
         <source>&quot;%1&quot; was successfully created</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 koopiat edukalt loodud</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="89"/>
         <source>Unable to create the theme archive &quot;%1&quot;.
 The following errors were reported:
 %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Ei suuda luua teemaarhiivi &quot;%1&quot;.
+Raporteeriti järgmised veateated:
+%2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="95"/>
         <location filename="../archive.cpp" line="178"/>
         <source>Unable to run the &quot;tar&quot; command: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;tar&quot; käsu käivitamine nurjus: %s</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="115"/>
         <source>Unable to create directory &quot;%1&quot;: %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Ei saa luua kataloogi &quot;%1&quot;: %2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="138"/>
         <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%s&quot; ei paista olema kehtiv Openbox teema kataloog</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="148"/>
         <source>Unable to move to directory &quot;%1&quot;: %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Kataloogi &quot;%1&quot; ei saa liigutada: %2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="185"/>
@@ -664,12 +682,15 @@ The following errors were reported:
 Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
 The following errors were reported:
 %3</source>
-        <translation type="unfinished"></translation>
+        <translation>Faili &quot;%1&quot; ei saa ekstraheerida.
+Palun veenduge, et &quot;%2&quot; on kirjutatav ja et fail on kehtiv Openboxi teema arhiiv.
+Teatati järgmistest vigadest:
+%3</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="53"/>
         <source>ObConf Error</source>
-        <translation type="unfinished"></translation>
+        <translation>ObConfi viga</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="58"/>
@@ -683,7 +704,15 @@ This is free software, and you are welcome to redistribute it
 under certain conditions. See the file COPYING for details.
 
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Autoriõigus (c) 2003-2008 Dana Jansens
+Autoriõigus (c) 2003 Tim Riley
+Autoriõigus (c) 2007 jaavered shaikh
+Autoriõigus (c) 2013 Hong Jen Yee (PCMAN)
+
+See programm on absoluutselt mingit garantiid.
+See on tasuta tarkvara ja olete teretulnud selle ümberjaotamiseks
+teatavatel tingimustel. Vaata faili kopeerimine üksikasju. 
+</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="73"/>
@@ -696,43 +725,56 @@ Options:
   --archive THEME       Create a theme archive from the given theme directory
   --config-file FILE    Specify the path to the config file to use
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Süntaksi: OBCONF [Valikud] [Arhiiv.obt]
+
+Valikud:
+   --help Kuvage see abi ja väljumine
+   - versiooni kuvamine ja väljumine
+   --install archive.obt installige antud teema arhiiv ja valige see
+   - &quot;Teema Loo teema arhiiv antud teema kataloogi
+   - Aconfig-faili fail Määrake kasutatava konfigureerimisfaili tee 
+</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="97"/>
         <source>--install requires an argument
 </source>
-        <translation type="unfinished"></translation>
+        <translation>--install nõuab argumenti
+</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="103"/>
         <source>--archive requires an argument
 </source>
-        <translation type="unfinished"></translation>
+        <translation>--archive nõuab argumenti
+</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="109"/>
         <source>--config-file requires an argument
 </source>
-        <translation type="unfinished"></translation>
+        <translation>--config-file nõuab argumenti
+</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="223"/>
         <location filename="../obconf-qt.cpp" line="238"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Viga</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="224"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
-        <translation type="unfinished"></translation>
+        <translation>Faili rc.xml laadimine nurjus. Võimalik, et Openboxi paigaldamine jäi vigaseks.</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="236"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Openboxi seadistustefaili parsimisel tekkis viga. Seadistustefail ei ole korrektsel kujul XML.
+
+Teade: %s</translation>
     </message>
 </context>
 </TS>
